summaryrefslogtreecommitdiff
path: root/nuttx/net/udp
diff options
context:
space:
mode:
authorGregory Nutt <gnutt@nuttx.org>2014-07-06 17:22:02 -0600
committerGregory Nutt <gnutt@nuttx.org>2014-07-06 17:22:02 -0600
commitde7f2c8553da00529baa9ba6d2faaf7721d0506d (patch)
tree3359191c655307f23ecdd5b46dbf3f5bbcbb486e /nuttx/net/udp
parent13df5a4fc813c0744f78d40fed3c1e36485fe5a6 (diff)
downloadnuttx-de7f2c8553da00529baa9ba6d2faaf7721d0506d.tar.gz
nuttx-de7f2c8553da00529baa9ba6d2faaf7721d0506d.tar.bz2
nuttx-de7f2c8553da00529baa9ba6d2faaf7721d0506d.zip
NET: Rename network interrupt event flags more appropriately: TCP_, UDP_, ICMP_, or PKT_ vs UIP_
Diffstat (limited to 'nuttx/net/udp')
-rw-r--r--nuttx/net/udp/udp_input.c6
-rw-r--r--nuttx/net/udp/udp_poll.c2
2 files changed, 4 insertions, 4 deletions
diff --git a/nuttx/net/udp/udp_poll.c b/nuttx/net/udp/udp_poll.c
index 03f395952..1007adff0 100644
--- a/nuttx/net/udp/udp_poll.c
+++ b/nuttx/net/udp/udp_poll.c
@@ -108,7 +108,7 @@ void udp_poll(FAR struct net_driver_s *dev, FAR struct udp_conn_s *conn)
/* Perform the application callback */
- (void)udp_callback(dev, conn, UIP_POLL);
+ (void)udp_callback(dev, conn, UDP_POLL);
/* If the application has data to send, setup the UDP/IP header */
diff --git a/nuttx/net/udp/udp_input.c b/nuttx/net/udp/udp_input.c
index aaaa5a795..07699c8f6 100644
--- a/nuttx/net/udp/udp_input.c
+++ b/nuttx/net/udp/udp_input.c
@@ -142,13 +142,13 @@ int udp_input(FAR struct net_driver_s *dev)
/* Perform the application callback */
- flags = udp_callback(dev, conn, UIP_NEWDATA);
+ flags = udp_callback(dev, conn, UDP_NEWDATA);
- /* If the operation was successful, the UIP_NEWDATA flag is removed
+ /* If the operation was successful, the UDP_NEWDATA flag is removed
* and thus the packet can be deleted (OK will be returned).
*/
- if ((flags & UIP_NEWDATA) != 0)
+ if ((flags & UDP_NEWDATA) != 0)
{
/* No.. the packet was not processed now. Return ERROR so
* that the driver may retry again later.